@@ -5,3 +5,7 @@ __all__ = []
 from . import core
 __all__.extend(core.__all__)
 from .core import *
+
+from . import bot
+__all__.extend(bot.__all__)
+from .bot import *
