@@ -24,10 +24,6 @@ from . import bTrader
 __all__.extend(bTrader.__all__)
 from .bTrader import *
 
-from . import TradeWorker
-__all__.extend(TradeWorker.__all__)
-from .TradeWorker import *
-
 from . import Logger
 __all__.extend(Logger.__all__)
 from .Logger import *
\ No newline at end of file
